@@ -1,11 +1,11 @@
 /*
- *	event.h
+ *    event.h
  *
- *	Include file for event.c
+ *    Include file for event.c
  *
- *	Copyright Jeroen Vreeken, 2002
- *	This software is distributed under the GNU Public License Version 2
- *	see also the file 'COPYING'.
+ *    Copyright Jeroen Vreeken, 2002
+ *    This software is distributed under the GNU Public License Version 2
+ *    see also the file 'COPYING'.
  *
  */
 #ifndef _INCLUDE_EVENT_H_
@@ -27,7 +27,8 @@
 #define EVENT_FILECLOSE         16384
 #define EVENT_DEBUG             65536
 #define EVENT_CRITICAL          131072
-#
+#define EVENT_AREA_DETECTED     262144
+#define EVENT_CAMERA_LOST       524288
 
 typedef void(* event_handler)(struct context *, int, unsigned char *, char *, void *, struct tm *);
 
