@@ -164,7 +164,7 @@ static int file_write(URLContext *h, unsigned char *buf, int size)
     return write(fd, buf, size);
 }
 
-static offset_t file_seek(URLContext *h, offset_t pos, int whence)
+static int64_t file_seek(URLContext *h, int64_t pos, int whence)
 {
     int fd = (size_t)h->priv_data;
     return lseek(fd, pos, whence);
@@ -183,6 +183,11 @@ URLProtocol file_protocol = {
     file_write,
     file_seek,
     file_close,
+#if LIBAVFORMAT_BUILD >= (52<<16 | 31<<8)
+    NULL,
+    NULL,
+    NULL,
+#endif    
 };
 
 #endif
@@ -223,7 +228,11 @@ void ffmpeg_init()
     mpeg1_file_protocol.url_close = file_protocol.url_close;
 
     /* Register the append file protocol. */
+#if LIBAVFORMAT_BUILD >= (52<<16 | 31<<8)
+    av_register_protocol(&mpeg1_file_protocol);
+#else
     register_protocol(&mpeg1_file_protocol);
+#endif
 }
 
 /* Obtains the output format used for the specified codec. For mpeg4 codecs,
@@ -275,13 +284,14 @@ static AVOutputFormat *get_oformat(const char *codec, char *filename)
     } else if (strcmp(codec, "flv") == 0) {
         ext = ".flv";
         of = guess_format("flv", NULL, NULL);
+        of->video_codec = CODEC_ID_FLV1;
     } else if (strcmp(codec, "ffv1") == 0) {
         ext = ".avi";
         of = guess_format("avi", NULL, NULL);
         if (of) {
             /* Use the FFMPEG Lossless Video codec (experimental!).
                Requires strict_std_compliance to be <= -2 */
-            of->video_codec = CODEC_ID_FLV1;
+            of->video_codec = CODEC_ID_FFV1;
         }
     } else if (strcmp(codec, "mov") == 0) {
         ext = ".mov";
