@@ -1,5 +1,5 @@
 /*
- *	picture.h
+ *    picture.h
  *
  *      Copyright 2002 by Jeroen Vreeken (pe1rxq@amsat.org)
  *      Portions of this file are Copyright by Lionnel Maugis
@@ -20,6 +20,6 @@ void put_picture_fd(struct context *, FILE *, unsigned char *, int);
 int put_picture_memory(struct context *, unsigned char*, int, unsigned char *, int);
 void put_picture(struct context *, char *, unsigned char *, int );
 unsigned char *get_pgm(FILE *, int, int);
-void preview_best(struct context *);
+void preview_save(struct context *);
 
 #endif /* _INCLUDE_PICTURE_H_ */
