@@ -294,7 +294,7 @@ void conv_uyvyto420p(unsigned char *map, unsigned char *cap_map, unsigned int wi
     uint8_t *pY = map;
     uint8_t *pU = pY + (width * height);
     uint8_t *pV = pU + (width * height) / 4;
-    uint32_t uv_offset = width * 4 * sizeof(uint8_t);
+    uint32_t uv_offset = width * 2 * sizeof(uint8_t);
     uint32_t ix, jx;
 
     for (ix = 0; ix < height; ix++) {
@@ -415,7 +415,8 @@ int mjpegtoyuv420p(unsigned char *map, unsigned char *cap_map, int width, int he
     ret = decode_jpeg_raw(cap_map, size, 0, 420, width, height, yuv[0], yuv[1], yuv[2]);
     
     if (ret == 1) {
-        motion_log(LOG_ERR, 0, "%s: Corrupt image ... continue", __FUNCTION__);
+        if (debug_level >= CAMERA_WARNINGS)
+            motion_log(LOG_ERR, 0, "%s: Corrupt image ... continue", __FUNCTION__);
         ret = 2;
     }
 
@@ -597,8 +598,7 @@ void vid_close(struct context *cnt)
         } else {
 #endif
             close(dev->fd);
-            munmap(viddevs->v4l_buffers[0], viddevs->size_map);
-            munmap(viddevs->v4l_buffers[1], viddevs->size_map);
+            munmap(viddevs->v4l_buffers[0], dev->size_map);
 #ifdef MOTION_V4L2
         }
 #endif
