@@ -12,7 +12,11 @@
 
 #ifndef WITHOUT_V4L
 
-#ifdef OLD_BKTR
+#ifdef __NetBSD__
+#include <dev/ic/bt8xx.h>
+#elif __OpenBSD__
+#include <dev/ic/bt8xx.h>
+#elif defined(OLD_BKTR)
 #include <machine/ioctl_meteor.h>
 #include <machine/ioctl_bt848.h>
 #else
@@ -20,7 +24,6 @@
 #include <dev/bktr/ioctl_bt848.h>
 #endif
 
-
 #endif
 
 /* bktr (video4linux) stuff FIXME more modes not only these */
